angular
    .module('selae.user.controllers')
    .controller('UserProfileCtrl', UserProfileCtrl);
    
    UserProfileCtrl.$inject = [
        '$rootScope', 
        '$http', 
        '$filter', 
        'popupSrv', 
        'requestSrv', 
        'config',
        '$state'
    ];

    function UserProfileCtrl( $rootScope, $http, $filter, popupSrv, requestSrv, config, $state) {
        'use strict';

        var vm = this;

        popupSrv.showLoading('Comprobando datos');

        vm.verificateCall = function(plugin) {
            // Vemos si el usuario está verificado documentalmente"https://host/jugar/participante/estado"
            var callConfig = {
                headers : {
                    "Content-Type": "application/json",
                },
                data : ''
            }
    
            $http.get( window.cordova ? window.WebviewProxy.convertProxyUrl(config.services.hostFiltro + config.services.profileUserData) : config.services.hostFiltro + config.services.profileUserData, callConfig )
            .then(function(e) {
                vm.user = e.data.usuarioWebDto[0];
    
                // Modificamos la fecha de nacimiento para mostrarla como la pide Selae
                if (vm.user.fechaNacimiento.search("CET") !== -1) {
                    vm.user.fechaNacimiento = $filter('date')(new Date(vm.user.fechaNacimiento.replace(/CET/, '')), "dd/MM/yyyy");
                } else {
                    vm.user.fechaNacimiento = $filter('date')(new Date(vm.user.fechaNacimiento.replace(/CEST/, '')), "dd/MM/yyyy");
                }
                vm.user.telefonoMovil = e.data.telefonoMovil[0];
                popupSrv.hideLoading();
                
                
            }), function(error) {
                console.log("error en datos de usuario", error);
                popupSrv.hideLoading();
                popupSrv.showErrorPopup(requestSrv.errorHandler2(error));  
            };


            $http.get( window.cordova ? window.WebviewProxy.convertProxyUrl(config.services.hostFiltro + config.services.profileIsVerificate) : config.services.hostFiltro + config.services.profileIsVerificate, callConfig)
            .then(function(e){
                if (plugin) {
                    popupSrv.hideLoading();
                }
                if (e.data.estado === "BLOQUEADO" && e.data.motivos[0]) {
                    vm.pendienteVerificar = true;
                } else {
                    vm.pendienteVerificar = false;
                }
            }), function(error) {
                popupSrv.hideLoading();
                // error llamada inicial metemos manejador de errores comun y error si venimos del plugin mostramos popUp de error y mandamos a home
                if (plugin) {
                    popupSrv.showErrorPopup("perfilErrorVerif");
                    $state.go("app.home");
                } else {
                    popupSrv.showErrorPopup(requestSrv.errorHandler2(error));
                }
                console.log("Error en pregunta verificación de perfil", error);
            };
        };

        vm.verificateCall();

        vm.launchSDK = function() {

        // Funcion para configurar el entorno de IECISA
        var dinamicBearer = function () {
            var bearer = {
                'pro': "03906849-2488-393c-a4e1-fa94adaea50d",
                'int7':"8281c40c-6cb7-3962-947b-ff16c3fb84b2",
                'int3':"3e5df3d9-51c1-3832-bb65-03fecb130155"
            }
            return bearer[selae.entorno] || bearer['pro']
        };

        var dinamicEnvironment = function() {
            var environment = {
                'pro': "PRO",
                'int7':"PRE",
                'int3':"PRE"
            }
            return environment[selae.entorno] || environment['pro']
        };

        var theme = {
            header: true,
            isShow_logo_step_end: false,
            primary_color: "0e3f62", // HEX
            secondary_color: "6A6A6A",
            tertiary_color: "000000",
            frame1_color: "FFFFFF",
            frame2_color: "0e3f62",
            frame3_color: "008000",
            title1_color: "0e3f62",
            title2_color: "000000",
            primary_font: "Futura-Bold", // Font Name
            secondary_font: "OpenSans",
            tertiary_font: "OpenSans-Semibold",
            logo_color: "logo-color",
            id_front: "id_front",
            id_back: "id_back",
            user: "user",
            tick: "tick",
            start_screen_label_title_textAlignment: "center",
            start_screen_label_info_textAlignment: "center",
            middle_screen_label_title_textAligment: "center",
            middle_screen_label_info_textAligment: "center",
            end_screen_label_info_textAligment: "center",
            info_screen_label_info_textAlignment: "center",
            end_screen_tick_rostro_color: "0e3f62",
            button_corner_radius: 10,
            button_border_width: 1,
            button_border_color: "0e3f62",
            button_font_color: "0e3f62",
            button_color: "FFFFFF",
            contactPhoneNumber: "900 294 105"
        };

        var textsStepInitial = {
            step_initial_info: $filter('translate')('step_initial_info'),
            agreement_button_text: $filter('translate')('agreement_button_text'),
            step_initial_obverse: $filter('translate')('step_initial_obverse'),
            step_initial_reverse: $filter('translate')('step_initial_reverse'),
            step_initial_face: $filter('translate')('step_initial_face'),
            start_button: $filter('translate')('start_button'),
            status_evidence_finished: $filter('translate')('status_evidence_finished')
        }

        var textsStepInfo = {
            step_info_title_card: $filter('translate')('step_info_title_card'),
            step_info_card: $filter('translate')('step_info_card'),
            step_info_video: $filter('translate')('step_info_video'),
            info_continue_button: $filter('translate')('info_continue_button')
        }

        var textsCaptureCardFront = {
            step_card_title_front: $filter('translate')('step_card_title_front'),
            info_card_front: $filter('translate')('info_card_front'),
            info_card_upload: $filter('translate')('info_card_upload'),
            status_scanning_doc_front: $filter('translate')('status_scanning_doc_front'),
            status_card_front_finished: $filter('translate')('status_card_front_finished')
        }

        var textsCaptureCardBack = {
            step_card_title_reverse: $filter('translate')('step_card_title_reverse'),
            info_card_reverse: $filter('translate')('info_card_reverse'),
            info_card_upload: $filter('translate')('info_card_upload'),
            status_scanning_doc_back: $filter('translate')('status_scanning_doc_back'),
            status_evidence_reverse_finished: $filter('translate')('status_evidence_reverse_finished'),
            error_camera_no_permissions: $filter('translate')('error_camera_no_permissions'),
            info_face_evidence_upload: $filter('translate')('info_face_evidence_upload'),
            status_card_back_finished: $filter('translate')('status_card_back_finished')
        }

        var textsMiddleVideo = {
            step_middle_info: $filter('translate')('step_middle_info'),
            agreement_button_text_video: $filter('translate')('agreement_button_text_video'),
            middle_button: $filter('translate')('middle_button')
        }

        var textsVideoCall = {
            step_video_title: $filter('translate')('step_video_title'),
            info_face_detection_change: $filter('translate')('info_face_detection_change'),
            info_face_detection_success: $filter('translate')('info_face_detection_success'),
            info_face_turn_document: $filter('translate')('info_face_turn_document'),
            info_face_turn_document_anverse: $filter('translate')('info_face_turn_document_anverse'),
            info_badwidth: $filter('translate')('info_badwidth'),
            status_initiating: $filter('translate')('status_initiating'),
            status_recording: $filter('translate')('status_recording'),
            info_face: $filter('translate')('info_face'),
            status_no_detection: $filter('translate')('status_no_detection'),
            status_success: $filter('translate')('status_success'),
            status_evidence_finished: $filter('translate')('status_evidence_finished'),
            status_evidence_reverse_finished: $filter('translate')('status_evidence_reverse_finished'),
            info_face_evidence_upload: $filter('translate')('info_face_evidence_upload'),
        }

        var textsStepEnd = {
            step_final_info: $filter('translate')('step_final_info'),
            step_final_finish: $filter('translate')('step_final_finish'),
            iecisa_id_front_end: $filter('translate')('iecisa_id_front_end'),
            iecisa_id_back_end: $filter('translate')('iecisa_id_back_end'),
            iecisa_step_your_face_end: $filter('translate')('iecisa_step_your_face_end'),
            step_final_obverse: $filter('translate')('step_final_obverse'),
            step_final_reverse: $filter('translate')('step_final_reverse'),
            step_final_face: $filter('translate')('step_final_face'),
            agreement_final_text: $filter('translate')('agreement_final_text'),
            end_button: $filter('translate')('end_button')
        }

        var textsError = {
                /* COMUNES */
            error_title: $filter('translate')('error_title'),
            error_title_video: $filter('translate')('error_title_video'),
            error_button_go_init: $filter('translate')('error_button_go_init'),
            error_button: $filter('translate')('error_button'),
            error_button_cancel: $filter('translate')('error_button_cancel'),
            error_fatal_error_description: $filter('translate')('error_fatal_error_description'),
            error_fatal_error_subdescription: $filter('translate')('error_fatal_error_subdescription'),
            error_network_description: $filter('translate')('error_network_description'),
                
                /* PROPIOS de iOS */
            error_network_subdescription: $filter('translate')('error_network_subdescription'),
            error_description_camera: $filter('translate')('error_description_camera'),  
            error_description_video: $filter('translate')('error_description_video'),
            error_camera_no_permissions: $filter('translate')('error_camera_no_permissions'),
                
                /* PROPIOS de Android */
            iecisa_scan_something_wrong: $filter('translate')('iecisa_scan_something_wrong'),
            iecisa_try_following: $filter('translate')('iecisa_try_following'),
            iecisa_put_doc_plain_surface: $filter('translate')('iecisa_put_doc_plain_surface'),
            iecisa_check_luminance: $filter('translate')('iecisa_check_luminance'),
            iecisa_not_spots_or_darks: $filter('translate')('iecisa_not_spots_or_darks'),
            iecisa_match_image_in_guide: $filter('translate')('iecisa_match_image_in_guide'),  
            iecisa_doc_scan_interrupted: $filter('translate')('iecisa_doc_scan_interrupted'),
            iecisa_reinit_doc_scan: $filter('translate')('iecisa_reinit_doc_scan'),
            iecisa_facial_scan_interrupted: $filter('translate')('iecisa_facial_scan_interrupted'),
            iecisa_reinit_facial_scan: $filter('translate')('iecisa_reinit_facial_scan'),
            iecisa_push_open_cam_to_resume_scan: $filter('translate')('iecisa_push_open_cam_to_resume_scan'),
            iecisa_some_went_wrong_while_facial_scan: $filter('translate')('iecisa_some_went_wrong_while_facial_scan'),
            iecisa_place_yourself_lighty: $filter('translate')('iecisa_place_yourself_lighty'),
            iecisa_place_face_inside_guide: $filter('translate')('iecisa_place_face_inside_guide'),
            iecisa_look_front_cam: $filter('translate')('iecisa_look_front_cam'),
            iecisa_video_streaming_low_bps: $filter('translate')('iecisa_video_streaming_low_bps'),
            iecisa_check_your_mobile_conn: $filter('translate')('iecisa_check_your_mobile_conn'),
            iecisa_place_yourself_coverage_site: $filter('translate')('iecisa_place_yourself_coverage_site'),
            iecisa_avoid_low_coverage_sites: $filter('translate')('iecisa_avoid_low_coverage_sites'),
            iecisa_could_not_send_evidences: $filter('translate')('iecisa_could_not_send_evidences'),
            iecisa_net_problem: $filter('translate')('iecisa_net_problem'),
            iecisa_push_init_to_repeat: $filter('translate')('iecisa_push_init_to_repeat'),
            iecisa_have_good_coverage: $filter('translate')('iecisa_have_good_coverage'),
            iecisa_have_internet: $filter('translate')('iecisa_have_internet'),
            iecisa_error_server_connection: $filter('translate')('iecisa_error_server_connection'), 
            iecisa_info_lost_net: $filter('translate')('iecisa_info_lost_net'),
            iecisa_error_server_try_again: $filter('translate')('iecisa_error_server_try_again'),
            iecisa_error_streaming_server_interrupted: $filter('translate')('iecisa_error_streaming_server_interrupted'),
            iecisa_check_error: $filter('translate')('iecisa_check_error'),
            iecisa_bad_quality_image_check: $filter('translate')('iecisa_bad_quality_image_check'),
            iecisa_invalid_document_type: $filter('translate')('iecisa_invalid_document_type'),
            iecisa_expired_document: $filter('translate')('iecisa_expired_document'),
            iecisa_no_coincidence_back_front: $filter('translate')('iecisa_no_coincidence_back_front'),
            iecisa_could_not_init_workflow_in_device: $filter('translate')('iecisa_could_not_init_workflow_in_device'),
            iecisa_close_process_and_retry: $filter('translate')('iecisa_close_process_and_retry'),
            iecisa_push_to_close_process: $filter('translate')('iecisa_push_to_close_process'),
            iecisa_camera_reject_tip_1: $filter('translate')('iecisa_camera_reject_tip_1'),
            iecisa_camera_reject_tip_2: $filter('translate')('iecisa_camera_reject_tip_2'),
            iecisa_camera_reject_tip_3: $filter('translate')('iecisa_camera_reject_tip_3'),
            iecisa_audio_reject_tip_1: $filter('translate')('iecisa_audio_reject_tip_1'),
            iecisa_audio_reject_tip_2: $filter('translate')('iecisa_audio_reject_tip_2'),
            iecisa_audio_reject_tip_3: $filter('translate')('iecisa_audio_reject_tip_3'),
            iecisa_could_not_rec_video_contact_phone: $filter('translate')('iecisa_could_not_rec_video_contact_phone'),
            help_phone: $filter('translate')('help_phone'),
            iecisa_processing_image: $filter('translate')('iecisa_processing_image'),
        }

        var textsHelp = {
            step_help_title: $filter('translate')('step_help_title'),
            help_button: $filter('translate')('help_button'),

            step_help_text1_card: $filter('translate')('step_help_text1_card'),
            step_help_text2_card: $filter('translate')('step_help_text2_card'),
            step_help_text3_card: $filter('translate')('step_help_text3_card'),
            step_help_text4_card: $filter('translate')('step_help_text4_card'),

            step_help_text1_face: $filter('translate')('step_help_text1_face'),
            step_help_text2_face: $filter('translate')('step_help_text2_face'),
            step_help_text3_face: $filter('translate')('step_help_text3_face'),
            step_help_text4_face: $filter('translate')('step_help_text4_face'),
            step_help_text5_face: $filter('translate')('step_help_text5_face')
        }

        var texts = {
            textsStepInitial: textsStepInitial,
            textsStepInfo: textsStepInfo,
            textsCaptureCardFront: textsCaptureCardFront,
            textsCaptureCardBack: textsCaptureCardBack,
            textsMiddleVideo: textsMiddleVideo,
            textsVideoCall: textsVideoCall,
            textsStepEnd: textsStepEnd,
            textsError: textsError,
            textsHelp: textsHelp
        };
        
        var config = {
            upload_check: true,
            bearer: dinamicBearer(),
            clean_view_stack: true,
            identifiers: ["ESP"],
            environment: dinamicEnvironment(),
            texts: texts,
            theme: theme,
            flow: ["initial", "info_capture_card", "capture_card_front", "capture_card_reverse", "middle", "info_capture_face", "capture_face_call", "final"],
            show_card_frame: false,
            capture_rotation: false,
            show_cancel_error: false,
            step_max_retries: 3,
            step_max_timeout: 30,
            min_bitrate: 500,
            videoDuration: 12.0,
            videoMessages: false,
            bam_enabled: true,
            bam_uid: vm.DoBInfo.userID
        };
        
                
            console.log("vamos a llamar al plugin de verificacion documental");
            startSdkDob.start({ 'config': config }, { 'uid': vm.DoBInfo.userID }, {'tokenDob':vm.DoBInfo.tokenDoB},
                function () {
                    console.log("Entramos por callback de exito.");
                    var delayTime = $rootScope.selae.properties.perfilTimer || 1000;
                    console.log("delay time= ",delayTime);
                    popupSrv.showLoading('Comprobando datos');
                    setTimeout( function() {
                        vm.verificateCall(true); 
                    }, delayTime);
                    console.log("We finish success!!");
                },
                function (error) {
                    console.log('Entramos por callback de Error.');
                    console.log(error);
                    popupSrv.showErrorPopup('perfilErrorPlugin', null, $filter('translate')('perfilErrorPluginNoFotoURL'));
                },
                {});
        }

        vm.verificate = function() {
            // Este dato está an local storage porque es uno por sesión, no tiene que persistir entre sesiones
            var participanteId = vm.user.identificador;
            var params = { "tipoFlujo": "2",
                            "participanteId": participanteId,
                            'documentType':'',
                            'document':vm.user.dni
                        };
            $http.post( window.cordova ? window.WebviewProxy.convertProxyUrl(config.services.host + config.services.profileVerify) : config.services.host + config.services.profileVerify, params)
            .then(function (e) {
                console.log(e)
                vm.DoBInfo = e.data.response;
                vm.launchSDK();
                
            }, function(error) {
                console.log("Error en recopilacion de datos para verificación de perfil",error)
            }); 
        }

        vm.noLink = $rootScope.selae.properties.perfilNoFotoURL || 'false';

        vm.noFoto = function() {
            window.open($filter("translate")("perfilNoFotoURL"), '_system', 'location=no');
        }
}
